@@ -49,14 +49,10 @@ from .types import (
     TSVectorType,
     URLType,
     UUIDType,
-    INT4RANGE,
-    INT8RANGE,
-    DATERANGE,
-    NUMRANGE,
 )
 
 
-__version__ = '0.23.1'
+__version__ = '0.23.2'
 
 
 __all__ = (
@@ -111,8 +107,4 @@ __all__ = (
     TSVectorType,
     URLType,
     UUIDType,
-    INT4RANGE,
-    INT8RANGE,
-    DATERANGE,
-    NUMRANGE,
 )
