@@ -70,6 +70,15 @@ Simple aggregates
         thread_id = sa.Column(sa.Integer, sa.ForeignKey(Thread.id))
 
 
+    thread = Thread(name=u'SQLAlchemy development')
+    thread.comments.append(Comment(u'Going good!'))
+    thread.comments.append(Comment(u'Great new features!'))
+
+    session.add(thread)
+    session.commit()
+
+    thread.comment_count  # 2
+
 
 
 Custom aggregate expressions
@@ -198,6 +207,9 @@ to define lots of relationships pointing to same class, remember to define the r
 Multi-level aggregates
 ----------------------
 
+Aggregates can span accross multiple relationships. In the following example each
+Catalog has a net_worth which is the sum of all products in all categories.
+
 
 ::
 
@@ -236,6 +248,49 @@ Multi-level aggregates
         category_id = sa.Column(sa.Integer, sa.ForeignKey(Category.id))
 
 
+Examples
+--------
+
+Average movie rating
+^^^^^^^^^^^^^^^^^^^^
+
+::
+
+
+    from sqlalchemy_utils import aggregated
+
+
+    class Movie(Base):
+        __tablename__ = 'movie'
+        id = sa.Column(sa.Integer, primary_key=True)
+        name = sa.Column(sa.Unicode(255))
+
+        @aggregated('ratings', sa.Column(sa.Numeric))
+        def avg_rating(self):
+            return sa.func.sum(Product.price)
+
+        ratings = sa.orm.relationship('Rating')
+
+
+    class Rating(Base):
+        __tablename__ = 'rating'
+        id = sa.Column(sa.Integer, primary_key=True)
+        stars = sa.Column(sa.Integer)
+
+        movie_id = sa.Column(sa.Integer, sa.ForeignKey(Movie.id))
+
+
+    movie = Movie('Terminator 2')
+    movie.ratings.append(Rating(stars=5))
+    movie.ratings.append(Rating(stars=4))
+    movie.ratings.append(Rating(stars=3))
+    session.add(movie)
+    session.commit()
+
+    movie.avg_rating  # 4
+
+
+
 TODO
 ----
 
@@ -277,7 +332,7 @@ class AggregatedAttribute(declared_attr):
         self.relationship = relationship
 
     def __get__(desc, self, cls):
-        if not hasattr(cls, '__aggregates__'):
+        if '__aggregates__' not in cls.__dict__:
             cls.__aggregates__ = {}
         cls.__aggregates__[desc.fget.__name__] = {
             'expression': desc.fget,
@@ -409,7 +464,7 @@ class AggregationManager(object):
         )
 
     def update_generator_registry(self, mapper, class_):
-        if hasattr(class_, '__aggregates__'):
+        if '__aggregates__' in class_.__dict__:
             for key, value in six.iteritems(class_.__aggregates__):
                 relationships = []
                 rel_class = class_
